/*
 * Copyright (c) 2019 gematik - Gesellschaft für Telematikanwendungen der Gesundheitskarte mbH
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 *
 * You may obtain a copy of the License at
 *    http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package de.gematik.ti.sgd.crypto;

import org.slf4j.Logger;
import org.slf4j.LoggerFactory;

import java.io.FileInputStream;
import java.io.FileNotFoundException;
import java.io.InputStream;

public class ClasspathFileUtil {
    private static final Logger logger = LoggerFactory.getLogger(ClasspathFileUtil.class);

    private static final String CLASSPATH = "classpath:";

    public static InputStream getInputStreamForPath(String path) {
        if (path == null) {
            throw new NullPointerException("No path provided: '" + path + "'");
        } else if (path.startsWith(CLASSPATH)) {
            final String classpathPath = path.substring(CLASSPATH.length());
            logger.info("Getting resource as stream from path {}", classpathPath);
            return ClasspathFileUtil.class.getResourceAsStream(classpathPath);
        } else {
            try {
                return new FileInputStream(path);
            } catch (FileNotFoundException e) {
                throw new RuntimeException(e);
            }
        }
    }
}
