/*
 * Copyright (c) 2019 gematik - Gesellschaft für Telematikanwendungen der Gesundheitskarte mbH
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 *
 * You may obtain a copy of the License at
 *    http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package de.gematik.ti.sgd.components;

import de.gematik.ti.sgd.SgdTestCryptoUtilities;
import de.gematik.ti.sgd.crypto.SgdCryptoUtilities;
import org.junit.Test;

import java.io.File;
import java.security.cert.X509Certificate;

import static org.assertj.core.api.Assertions.assertThat;

public class SgdServerUtilsTest {
    private final String P12_EGK_FILENAME = "src/test/resources/keys/egk/109500969_X114428530_c.ch.aut-ecc.p12";
    private final String P12_SMCB_FILENAME = "src/test/resources/keys/smcb/833621999741621_c.hci.aut-arge-psych-ecc.p12";

    {
        SgdCryptoUtilities.setInstance(new SgdTestCryptoUtilities());
    }

    @Test
    public void convertSimpleTelematikId() {
        assertThat(SgdServerUtils.perform18003Conversion("foobar"))
                .isEqualTo("foobar");
    }

    @Test
    public void convertSpecTelematikId() {
        assertThat(SgdServerUtils.perform18003Conversion("2-20a1201-001:AAB::112"))
                .isEqualTo("*322d323061313230312d3030313a4141423a3a313132");
    }

    @Test
    public void extractTelematikIdFromSmcbCertificate() {
        X509Certificate smcbCertificate = SgdCryptoUtilities.getInstance().loadX509CertificateFromP12File(P12_SMCB_FILENAME, "00");

        assertThat(SgdCryptoUtilities.getInstance().extractTelematikIdFromCertificate(smcbCertificate))
                .contains("1-2-EPA-833621999741621");
    }

    @Test
    public void getKvnrForSmcb_shouldGiveEmptyOptional() {
        X509Certificate smcbCertificate = SgdCryptoUtilities.getInstance().loadX509CertificateFromP12File(P12_SMCB_FILENAME, "00");

        assertThat(SgdServerUtils.extractKVNRfromCertificate(smcbCertificate))
                .isEmpty();
    }

    @Test
    public void getKvnrForEgk_shouldGiveEmptyOptional() {
        X509Certificate egkCertificate = SgdCryptoUtilities.getInstance().loadX509CertificateFromP12File(P12_EGK_FILENAME, "00");

        assertThat(SgdServerUtils.extractKVNRfromCertificate(egkCertificate))
                .contains("X114428530");
    }
}