/*
 * Copyright (c) 2019 gematik - Gesellschaft für Telematikanwendungen der Gesundheitskarte mbH
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 *
 * You may obtain a copy of the License at
 *    http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package de.gematik.ti.sgd.domain;


import de.gematik.ti.sgd.domain.sgdCommunication.vectors.SgdVector;
import org.junit.Test;

import static org.assertj.core.api.Assertions.assertThat;
import static org.assertj.core.api.Assertions.assertThatThrownBy;

public class SgdVectorTest {
    @Test
    public void parseSgd1Vector_shouldHaveCorrectValues() {
        SgdVector vector = new SgdVector("r1:1234:107299005A112102647:ACME Q1-2019");

        assertThat(vector).hasFieldOrPropertyWithValue("type", "r1");
        assertThat(vector).hasFieldOrPropertyWithValue("rnd", "1234");
        assertThat(vector).hasFieldOrPropertyWithValue("kvnr", "107299005A112102647");
        assertThat(vector).hasFieldOrPropertyWithValue("keyDerivationName", "ACME Q1-2019");
    }

    @Test
    public void buildSgd1Vector_shouldResultInCorrectString() {
        SgdVector vector = SgdVector.createForR1RepeatedDerivation("1234",
                "107299005A112102647", "ACME Q1-2019");

        assertThat(vector.toString())
                .isEqualTo("r1:1234:107299005A112102647:ACME Q1-2019");
    }

    @Test
    public void buildInitialR1Vector_gettersShouldWorkAsExpected() {
        final String kvnr = "107299005A112102647";

        SgdVector vector = SgdVector.createForR1InitialDerivation(kvnr);

        assertThat(vector.getKvnr())
                .isEqualTo(kvnr);
        assertThatThrownBy(() -> vector.getKeyDerivationName())
                .isInstanceOf(RuntimeException.class);
        assertThatThrownBy(() -> vector.getRnd())
                .isInstanceOf(RuntimeException.class);
        assertThat(vector.getType())
                .isEqualTo("r1");
    }

    @Test
    public void buildIllFormattedR1Vector_shouldGiveException() {
        assertThatThrownBy(() -> new SgdVector("1:2:3"))
                .isInstanceOf(RuntimeException.class);
    }

    @Test
    public void buildInitialR2Vector_gettersShouldWorkAsExpected() {
        final String kvnr = "107299005A112102647";

        SgdVector vector = SgdVector.createForR2InitialDerivation(kvnr);

        assertThat(vector.getKvnr())
                .isEqualTo(kvnr);
        assertThatThrownBy(() -> vector.getKeyDerivationName())
                .isInstanceOf(RuntimeException.class);
        assertThatThrownBy(() -> vector.getRnd())
                .isInstanceOf(RuntimeException.class);
        assertThat(vector.getType())
                .isEqualTo("r2");
    }
}
