/*
 * Copyright (c) 2019 gematik - Gesellschaft für Telematikanwendungen der Gesundheitskarte mbH
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 *
 * You may obtain a copy of the License at
 *    http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package de.gematik.ti.sgd.domain.sgdCommunication;

import com.fasterxml.jackson.databind.ObjectMapper;
import com.jayway.jsonpath.DocumentContext;
import com.jayway.jsonpath.JsonPath;
import de.gematik.ti.sgd.domain.json.GetPublicKeyResponse;
import de.gematik.ti.sgd.domain.json.SgdResponse;
import org.junit.Test;

import static org.assertj.core.api.Assertions.assertThat;

// GemSpec_SGD_epa, A_17894
public class GetPublicKeyResponseJsonTest {
    @Test
    public void testSerialization() throws Exception {
        final ObjectMapper mapper = new ObjectMapper();

        final GetPublicKeyResponse getPublicKeyResponse = GetPublicKeyResponse.builder()
                .publicKeyEcies(new PublicKeyEcies("public key eceis"))
                .certificate("certificate")
                .signature("signature")
                .build();

        SgdResponse response = SgdResponse.create(getPublicKeyResponse);

        final DocumentContext result = JsonPath.parse(mapper.writeValueAsString(response));

        assertThat(result.read("@.PublicKeyECIES", String.class))
                .isEqualTo("public key eceis");
        assertThat(result.read("@.Signature", String.class))
                .isEqualTo("signature");
        assertThat(result.read("@.Certificate", String.class))
                .isEqualTo("certificate");
    }

    @Test
    public void testDeserialization() throws Exception {
        final ObjectMapper mapper = new ObjectMapper();

        final GetPublicKeyResponse getPublicKeyResponse = mapper.readerFor(GetPublicKeyResponse.class).readValue(
                "{ \"PublicKeyECIES\" : \"public key eceis\",\n" +
                        " \"Signature\" : \"signature\",\n" +
                        " \"Certificate\" : \"certificate\" }");
        assertThat(getPublicKeyResponse.getPublicKeyEcies().getMessage())
                .isEqualTo("public key eceis");
        assertThat(getPublicKeyResponse.getSignature())
                .isEqualTo("signature");
        assertThat(getPublicKeyResponse.getCertificate())
                .isEqualTo("certificate");
    }
}
