/*
 * Copyright (c) 2019 gematik - Gesellschaft für Telematikanwendungen der Gesundheitskarte mbH
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 *
 * You may obtain a copy of the License at
 *    http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package de.gematik.ti.sgd.server.configuration;

import de.gematik.ti.sgd.domain.SgdInstance;
import de.gematik.ti.sgd.domain.configuration.SgdInstanceProperties;
import lombok.AllArgsConstructor;
import lombok.Builder;
import lombok.Data;
import lombok.NoArgsConstructor;
import org.springframework.boot.context.properties.ConfigurationProperties;
import org.springframework.stereotype.Component;

import java.util.List;

@Component
@ConfigurationProperties("sgd")
@Data
@NoArgsConstructor
@AllArgsConstructor
@Builder
public class SgdServerConfiguration {
    private boolean isSgd1Instance;
    private List<String> signerCertificates;
    private String certificateP12;
    private String certificateP12Password;
    private String currentDerivationKeyName;
    private String currentDerivationKeyValue;

    public SgdInstanceProperties extractSgdInstanceProperties() {
        return SgdInstanceProperties.builder()
                .certificateP12(certificateP12)
                .certificateP12Password(certificateP12Password)
                .currentDerivationKeyName(currentDerivationKeyName)
                .currentDerivationKeyValue(currentDerivationKeyValue)
                .build();
    }

    public SgdInstance getConfiguredSgdInstance() {
        if (isSgd1Instance) {
            return SgdInstance.SGD_1;
        } else {
            return SgdInstance.SGD_2;
        }
    }
}
